==> ktp-text-ui_0.8.1.orig.tar.bz2: ktp-text-ui-0.8.1/filters/highlight/ktptextui_message_filter_highlight.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_highlight
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=highlight
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KDE-PluginInfo-Weight=10
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

Name=Highlight
Name[bs]=Naznačavanje
Name[ca]=Ressaltat
Name[ca@valencia]=Ressaltat
Name[cs]=Zvýraznění
Name[da]=Fremhævning
Name[de]=Hervorhebung
Name[el]=Τονισμός
Name[es]=Realce
Name[et]=Esiletõstmine
Name[fi]=Korostus
Name[fr]=Surligner
Name[gl]=Realzar
Name[hr]=Isticanje
Name[hu]=Kiemelés
Name[ia]=Evidentia
Name[it]=Evidenziazione
Name[kk]=Бояп белгілеген
Name[ko]=강조
Name[lt]=Paryškinti
Name[mr]=ठसवा
Name[nb]=Fremhev
Name[nds]=Rutheven
Name[nl]=Accentueren
Name[nn]=Markert melding
Name[pl]=Podświetl
Name[pt]=Realce
Name[pt_BR]=Realce
Name[ro]=Evidențiere
Name[ru]=Выделение сообщения
Name[se]=Merke
Name[sk]=Zvýraznenie
Name[sl]=Poudari
Name[sr]=Истицање
Name[sr@ijekavian]=Истицање
Name[sr@ijekavianlatin]=Isticanje
Name[sr@latin]=Isticanje
Name[sv]=Färglägg
Name[tr]=Vurgula
Name[ug]=يورۇت
Name[uk]=Підсвічування
Name[x-test]=xxHighlightxx
Name[zh_CN]=高亮
Name[zh_TW]=高亮度
Comment=If any incoming messages contain your nickname, it will highlight them in red
Comment[bs]=Ako dolazna poruka sadrži vaš nadimak, bit će naznačena crvenom bojom
Comment[ca]=Si qualsevol missatge entrant conté el vostre sobrenom, es ressaltarà en vermell.
Comment[ca@valencia]=Si qualsevol missatge entrant conté el vostre sobrenom, es ressaltarà en roig.
Comment[cs]=Pokud libovolná příchozí zpráva obsahuje vaši přezdívku bude zvýrazněna červeně
Comment[da]=Hvis indkommende beskeder indeholder dit kaldenavn, vil de blive fremhævet med rødt
Comment[de]=Wenn eine eingehende Nachricht Ihren Spitznamen enthält, wird sie rot hervorgehoben
Comment[el]=Τα εισερχόμενα μηνύματα που περιέχουν το ψευδώνυμό σας, θα τονίζονται με κόκκινο
Comment[es]=Esta opción resaltará en rojo cualquier mensaje entrante que contenga su apodo.
Comment[fi]=Jos saapuvassa viestissä on nimimerkkisi, viesti korostetaan punaisella
Comment[fr]=Si un quelconque message entrant contient votre pseudonyme, il le surlignera en rouge
Comment[gl]=Se algunha mensaxe entrante contén o seu alcume hanse realzar en vermello
Comment[hu]=Ha egy bejövő üzenet tartalmazza a becenevét, akkor az ki lesz emelve pirossal
Comment[ia]=Si qualcunque messages in arrivata contine tu pseudonymo, illo essera evidentiate in rubie
Comment[it]=Se in un messaggio ricevuto c'è scritto il tuo nick, sarà evidenziato in rosso
Comment[kk]=Егер кіріс хабарларында бүркеншік атыңыз пайда болғанда оны бояп белгілейді
Comment[ko]=별명을 포함하는 메시지를 받았을 때 붉은색으로 강조하기
Comment[lt]=Jei bet kuri gauta žinutė turi Jūsų slapyvardį, ji paryškins juos raudonai
Comment[nb]=Hvis noen meldinger inneholder kallenavnet ditt blir de fremhevet med rødt
Comment[nl]=Als een inkomend bericht uw schermnaam bevat, zal deze in rood geaccentueerd worden
Comment[pl]=Jeśli przychodząca wiadomość będzie zawierać twój pseudonim, to zostanie ona podświetlona na czerwono
Comment[pt]=Se alguma das mensagens recebidas tiver a sua alcunha, as mesmas ficarão realçadas a vermelho
Comment[pt_BR]=Se alguma mensagem recebida conter o seu apelido, ela será realçada em vermelho
Comment[ro]=Dacă vreun mesaj de intrare vă conține porecla, aceasta le va evidenția în roșu
Comment[ru]=Сообщения, содержащие ваше имя, будут выделяться красным
Comment[sk]=Ak nejaká prichádzajúca správa obsahuje vašu prezývku, bude zvýraznená červeno
Comment[sl]=Če bo katerokoli dohodno sporočilo vsebovalo vaš vzdevek, bo poudarjeno z rdečo
Comment[sr]=Када долазна порука садржи ваш надимак, биће истакнут црвеним
Comment[sr@ijekavian]=Када долазна порука садржи ваш надимак, биће истакнут црвеним
Comment[sr@ijekavianlatin]=Kada dolazna poruka sadrži vaš nadimak, biće istaknut crvenim
Comment[sr@latin]=Kada dolazna poruka sadrži vaš nadimak, biće istaknut crvenim
Comment[sv]=Om några inkommande meddelanden innehåller ditt smeknamn, färgläggs de med rött.
Comment[tr]=Eğer takma adınızı içeren bir gelen ileti varsa, kırmızı olarak vurgulanacak
Comment[uk]=Якщо вхідне повідомлення міститиме ваш псевдонім, програма позначить таке повідомлення червоним кольором
Comment[x-test]=xxIf any incoming messages contain your nickname, it will highlight them in redxx
Comment[zh_CN]=如果任何消息包含了您的昵称，将会用红色高亮显示
Comment[zh_TW]=如果傳送進來的訊息包含您的暱稱，則會以紅色突顯

==> ktp-text-ui-0.8.80.tar.bz2: ktp-text-ui-0.8.80/filters/highlight/ktptextui_message_filter_highlight.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_highlight
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=highlight
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KDE-PluginInfo-Weight=10
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

Name=Highlight
Name[bs]=Naznačavanje
Name[ca]=Ressaltat
Name[ca@valencia]=Ressaltat
Name[cs]=Zvýraznění
Name[da]=Fremhævning
Name[de]=Hervorhebung
Name[el]=Τονισμός
Name[en_GB]=Highlight
Name[es]=Realce
Name[et]=Esiletõstmine
Name[fi]=Korostus
Name[fr]=Surligner
Name[gl]=Realzar
Name[hu]=Kiemelés
Name[ia]=Evidentia
Name[it]=Evidenziazione
Name[kk]=Бояп белгілеген
Name[ko]=강조
Name[lt]=Paryškinti
Name[mr]=ठसवा
Name[nb]=Fremhev
Name[nds]=Rutheven
Name[nl]=Accentueren
Name[nn]=Markert melding
Name[pa]=ਉਭਾਰਨਾ
Name[pl]=Podświetlenie
Name[pt]=Realce
Name[pt_BR]=Realce
Name[ro]=Evidențiere
Name[ru]=Выделение сообщения
Name[se]=Merke
Name[sk]=Zvýraznenie
Name[sl]=Poudari
Name[sr]=Истицање
Name[sr@ijekavian]=Истицање
Name[sr@ijekavianlatin]=Isticanje
Name[sr@latin]=Isticanje
Name[sv]=Färglägg
Name[tr]=Vurgula
Name[ug]=يورۇت
Name[uk]=Підсвічування
Name[x-test]=xxHighlightxx
Name[zh_CN]=高亮
Name[zh_TW]=高亮度
Comment=If any incoming messages contain your nickname, it will highlight them in red
Comment[bs]=Ako dolazna poruka sadrži vaš nadimak, bit će naznačena crvenom bojom
Comment[ca]=Si qualsevol missatge entrant conté el vostre sobrenom, es ressaltarà en vermell.
Comment[ca@valencia]=Si qualsevol missatge entrant conté el vostre sobrenom, es ressaltarà en roig.
Comment[cs]=Pokud libovolná příchozí zpráva obsahuje vaši přezdívku bude zvýrazněna červeně
Comment[da]=Hvis indkommende beskeder indeholder dit kaldenavn, vil de blive fremhævet med rødt
Comment[de]=Wenn eine eingehende Nachricht Ihren Spitznamen enthält, wird sie rot hervorgehoben
Comment[el]=Τα εισερχόμενα μηνύματα που περιέχουν το ψευδώνυμό σας, θα τονίζονται με κόκκινο
Comment[en_GB]=If any incoming messages contain your nickname, it will highlight them in red
Comment[es]=Esta opción resaltará en rojo cualquier mensaje entrante que contenga su apodo.
Comment[et]=Kui sisenevas sõnumis esineb sinu hüüdnimi, tõstetakse see punasega esile
Comment[fi]=Jos saapuvassa viestissä on nimimerkkisi, viesti korostetaan punaisella
Comment[fr]=Si un quelconque message entrant contient votre pseudonyme, il le surlignera en rouge
Comment[gl]=Se algunha mensaxe entrante contén o seu alcume hanse realzar en vermello
Comment[hu]=Ha egy bejövő üzenet tartalmazza a becenevét, akkor az ki lesz emelve pirossal
Comment[ia]=Si qualcunque messages in arrivata contine tu pseudonymo, illo essera evidentiate in rubie
Comment[it]=Se in un messaggio ricevuto c'è scritto il tuo nick, sarà evidenziato in rosso
Comment[kk]=Егер кіріс хабарларында бүркеншік атыңыз пайда болғанда оны бояп белгілейді
Comment[ko]=별명을 포함하는 메시지를 받았을 때 붉은색으로 강조하기
Comment[lt]=Jei bet kuri gauta žinutė turi Jūsų slapyvardį, ji paryškins juos raudonai
Comment[nb]=Hvis noen meldinger inneholder kallenavnet ditt blir de fremhevet med rødt
Comment[nds]=Bargt en rinkamen Naricht Dien Ökelnaam, warrt he in root rutheevt
Comment[nl]=Als een inkomend bericht uw schermnaam bevat, zal deze in rood geaccentueerd worden
Comment[pa]=ਜੇ ਆ ਰਹੇ ਕਿਸੇ ਸੁਨੇਹੇ ਵਿੱਚ ਤੁਹਾਡਾ ਨਾਂ ਹੋਵੇ ਤਾਂ ਉਸਨੂੰ ਲਾਲ ਰਾਹੀਂ ਉਭਾਰੋ
Comment[pl]=Jeśli przychodząca wiadomość będzie zawierać twój pseudonim, to zostanie ona podświetlona na czerwono
Comment[pt]=Se alguma das mensagens recebidas tiver a sua alcunha, as mesmas ficarão realçadas a vermelho
Comment[pt_BR]=Se alguma mensagem recebida conter o seu apelido, ela será realçada em vermelho
Comment[ro]=Dacă vreun mesaj de intrare vă conține porecla, aceasta le va evidenția în roșu
Comment[ru]=Сообщения, содержащие ваше имя, будут выделяться красным
Comment[sk]=Ak nejaká prichádzajúca správa obsahuje vašu prezývku, bude zvýraznená červeno
Comment[sl]=Če bo katerokoli dohodno sporočilo vsebovalo vaš vzdevek, bo poudarjeno z rdečo
Comment[sr]=Када долазна порука садржи ваш надимак, биће истакнут црвеним
Comment[sr@ijekavian]=Када долазна порука садржи ваш надимак, биће истакнут црвеним
Comment[sr@ijekavianlatin]=Kada dolazna poruka sadrži vaš nadimak, biće istaknut crvenim
Comment[sr@latin]=Kada dolazna poruka sadrži vaš nadimak, biće istaknut crvenim
Comment[sv]=Om några inkommande meddelanden innehåller ditt smeknamn, färgläggs de med rött.
Comment[tr]=Eğer takma adınızı içeren bir gelen ileti varsa, kırmızı olarak vurgulanacak
Comment[uk]=Якщо вхідне повідомлення міститиме ваш псевдонім, програма позначить таке повідомлення червоним кольором
Comment[x-test]=xxIf any incoming messages contain your nickname, it will highlight them in redxx
Comment[zh_CN]=如果任何消息包含了您的昵称，将会用红色高亮显示
Comment[zh_TW]=如果傳送進來的訊息包含您的暱稱，則會以紅色突顯
